Pre-defined sources reference
=============================

Predefined sources are specified in ibidas.pre.
They can be accessed through `get`, e.g.::

   >>> feats = get.yeast_orfs()


.. automodule:: ibidas.pre
   :members:
   :undoc-members:
